@@ -1,15 +1,13 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "جهات الاتصال",
     "All contacts" : "كل الجهات",
     "Details" : "التفاصيل",
-    "Add a new picture" : "إضافة صورة جديدة",
+    "Contacts" : "جهات الاتصال",
+    "Upload a new picture" : "تحميل صورة جديدة",
     "Download picture" : "تنزيل الصورة",
     "Delete picture" : "حذف الصورة",
-    "Upload a new picture" : "تحميل صورة جديدة",
     "Invalid image" : "الصورة غير صالحة",
-    "Loading" : "Loading",
     "Name" : "الاسم",
     "Company" : "الشركة",
     "Title" : "العنوان",
@@ -19,7 +17,6 @@ OC.L10N.register(
     "Address book" : "دفتر العناوين",
     "Groups" : "مجموعات",
     "New contact" : "جهة إتصال جديدة",
-    "No errors" : "لا توجد أخطاء",
     "No results" : "دون أية نتيجة",
     "Last modified" : "آخر تعديل",
     "Rename" : "تعديل الإسم",
@@ -32,7 +29,10 @@ OC.L10N.register(
     "First name" : "الإسم",
     "Last name" : "اللقب",
     "Display name" : "الاسم المعروض",
+    "Group name" : "إسم الفريق",
     "Not grouped" : "غير مصنف",
+    "Close" : "إغلاق",
+    "Import" : "استيراد",
     "Nickname" : "كنية.\nلقب.",
     "Detailed name" : "الإسم بالتفصيل",
     "Additional names" : "الأسماء الإضافية",
@@ -67,7 +67,6 @@ OC.L10N.register(
     "Relative" : "مرتبط",
     "None" : "لا شيء",
     "Unknown" : "مجهول",
-    "Timezone" : "المنطقة الزمنية",
-    "An error occurred" : "طرأ هناك خطأ"
+    "Timezone" : "المنطقة الزمنية"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
