@@ -1,23 +1,21 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Contactos",
     "All contacts" : "Todos los contactos",
     "Details" : "Detalles",
+    "Contacts" : "Contactos",
     "A contacts app for Nextcloud" : "Una aplicación de contactos para Nextcloud",
     "Copy to full name" : "Copiar a nombre completo",
     "Omit year" : "Omitir año",
     "Add new property" : "Añadir nueva propiedad",
     "Choose property type" : "Elija el tipo de propiedad",
-    "Add a new picture" : "Agregar una nueva foto",
+    "Upload a new picture" : "Subir una nueva imagen",
     "Choose from files" : "Elige entre archivos",
     "Download picture" : "Descargar imágen",
-    "Upload a new picture" : "Subir una nueva imagen",
     "Invalid image" : "Imagen inválida",
     "Image is too big (max 1MB)." : "La imagen es demasiado grande (máximo 1MB).",
     "No contact selected" : "Contacto no seleccionado",
     "Select a contact on the list to begin" : "Seleccione un contacto en la lista para comenzar",
-    "Loading" : "Cargando",
     "Name" : "Nombre",
     "Company" : "Empresa",
     "Title" : "Título",
@@ -30,12 +28,11 @@ OC.L10N.register(
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentabas editar ha cambiado. Por favor actualice manualmente el contacto. Cualquier otra edición será descartada.",
     "Groups" : "Grupos",
     "New contact" : "Nuevo contacto",
-    "No errors" : "Sin errores",
-    "Open your browser console for more details" : "Abra la consola de su navegador para más detalles",
+    "The contact doesn't exists anymore on the server." : "El contacto ya no existe en el servidor.",
+    "No results" : "Sin resultados",
     "Select type" : "Seleccionar tipo",
     "Select Date" : "Seleccionar fecha",
     "Add contact in group" : "Añadir contacto en grupo",
-    "No results" : "Sin resultados",
     "Last modified" : "Última modificación",
     "Select option" : "Seleccionar opción",
     "Rename" : "Renombrar",
@@ -48,17 +45,18 @@ OC.L10N.register(
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "No users or groups" : "No hay usuarios ni grupos.",
     "can edit" : "poder editar",
-    "Unable to delete the share." : "No se puede eliminar el recurso compartido.",
-    "Unable to change permissions." : "No se pueden cambiar los permisos.",
     "Importing is disabled because there are no address books available" : "La importación está deshabilitada porque no hay libretas de direcciones disponibles",
     "Address book name" : "Nombre de la libreta de direcciones",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre para mostrar",
     "Sort by {sorting}" : "Ordenar por {sorting}",
+    "Group name" : "Nombre del grupo",
     "Not grouped" : "No agrupado",
     "Unable to create the contact." : "No se puede crear el contacto.",
     "Contact not found" : "Contacto no encontrado",
+    "Close" : "Cerrar",
+    "Import" : "Importar",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -95,9 +93,6 @@ OC.L10N.register(
     "Car" : "Coche",
     "Work pager" : "Buscapersonas de trabajo",
     "Social network" : "Red social",
-    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "La url del perfil. Por ejemplo: https://www.facebook.com/Nextclouders/",
-    "Relationship" : "Relación",
-    "Specify a relationship between you and the entity represented by this vCard." : "Especifique una relación entre usted y la entidad representada por esta vCard.",
     "Spouse" : "Cónyuge",
     "Child" : "Hijo",
     "Mother" : "Madre",
@@ -110,8 +105,6 @@ OC.L10N.register(
     "Colleague" : "Colega",
     "Manager" : "Gerente",
     "Assistant" : "Asistente",
-    "Related" : "Relacionado",
-    "Specify a relationship between another entity and the entity represented by this vCard." : "Especifique una relación entre otra entidad y la entidad representada por esta vCard.",
     "Contact" : "Contacto",
     "Agent" : "Agente",
     "Emergency" : "Emergencia",
@@ -121,7 +114,6 @@ OC.L10N.register(
     "Male" : "Masculino",
     "None" : "Ninguno",
     "Unknown" : "Desconocido",
-    "Timezone" : "Zona horaria",
-    "An error occurred" : "Ocurrió un error"
+    "Timezone" : "Zona horaria"
 },
 "nplurals=2; plural=(n != 1);");
