@@ -1,9 +1,9 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Kontakter",
     "All contacts" : "Alle kontakter",
     "Details" : "Detaljer",
+    "Contacts" : "Kontakter",
     "A contacts app for Nextcloud" : "En kontaktapp for Nextcloud",
     "Copy to full name" : "Kopier til fullt navn",
     "Add new property" : "Legg til felt",
@@ -13,7 +13,6 @@ OC.L10N.register(
     "Image is too big (max 1MB)." : "Bildet er for stort (opptil 1MB).",
     "No contact selected" : "Ingen kontakt valgt",
     "Select a contact on the list to begin" : "Velg en kontakt fra listen for å begynne",
-    "Loading" : "Laster",
     "Name" : "Navn",
     "Company" : "Bedrift",
     "Title" : "Tittel",
@@ -27,13 +26,11 @@ OC.L10N.register(
     "Groups" : "Grupper",
     "New contact" : "Ny kontakt",
     "Syntax error. Cannot open the contact." : "Syntaksfeil. Kan ikke åpne kontakten.",
-    "No errors" : "Ingen feil",
-    "Open your browser console for more details" : "Åpne din nettlesers konsoll for flere detaljer",
-    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} kontakt med feil","{failedCount} kontakter med feil"],
+    "Loading …" : "Laster...",
+    "No results" : "Ingen resultater",
     "Select type" : "Velg type",
     "Select Date" : "Velg dato",
     "Add contact in group" : "Legg kontakt til gruppe",
-    "No results" : "Ingen resultater",
     "Last modified" : "Sist endret",
     "Select option" : "Velg innstilling",
     "Rename" : "Gi nytt navn",
@@ -46,15 +43,18 @@ OC.L10N.register(
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
     "can edit" : "kan redigere",
-    "Unable to delete the share." : "Kan ikke slette delingen.",
     "Address book name" : "Adresseboksnavn",
     "First name" : "Fornavn",
     "Last name" : "Etternavn",
     "Display name" : "Visningsnavn",
     "Sort by {sorting}" : "Sorter etter {sorting}",
+    "Group name" : "Gruppenavn",
+    "Loading contacts …" : "Laster inn kontakter…",
     "Not grouped" : "Ikke gruppert",
     "Unable to create the contact." : "Kontakten kunne ikke opprettes.",
     "Contact not found" : "Kontakten ble ikke funnet",
+    "Close" : "Lukk",
+    "Import" : "Importer",
     "Nickname" : "Kallenavn",
     "Detailed name" : "Detaljert navn",
     "Additional names" : "Ev. mellomnavn",
@@ -76,7 +76,6 @@ OC.L10N.register(
     "Country" : "Land",
     "Birthday" : "Bursdag",
     "Anniversary" : "Jubileum",
-    "The date of marriage, or equivalent, of this contact" : "Datoen for ekteskapet, eller tilsvarende, for denne kontakten",
     "Date of death" : "Dødsdato",
     "Email" : "E-post",
     "Instant messaging" : "Direktemeldinger",
@@ -92,7 +91,6 @@ OC.L10N.register(
     "Car" : "Bil",
     "Work pager" : "Arbeidspersonsøker",
     "Social network" : "Sosialt nettverk",
-    "Relationship" : "Forhold",
     "Spouse" : "Ektefelle",
     "Child" : "Barn",
     "Mother" : "Mor",
@@ -105,7 +103,6 @@ OC.L10N.register(
     "Colleague" : "Kollega",
     "Manager" : "Sjef",
     "Assistant" : "Assistent",
-    "Related" : "I slekt",
     "Contact" : "Kontakt",
     "Emergency" : "Nødstilfelle",
     "Co-worker" : "Kollega",
@@ -115,7 +112,6 @@ OC.L10N.register(
     "None" : "Ingen",
     "Unknown" : "Ukjent",
     "Timezone" : "Tidssone",
-    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"],
-    "An error occurred" : "En feil oppstod"
+    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"]
 },
 "nplurals=2; plural=(n != 1);");
