@@ -1,11 +1,10 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "ข้อมูลผู้ติดต่อ",
     "All contacts" : "รายชื่อทั้งหมด",
     "Details" : "รายละเอียด",
+    "Contacts" : "ข้อมูลผู้ติดต่อ",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
-    "Loading" : "Loading",
     "Name" : "ชื่อ",
     "Title" : "ชื่อเรื่อง",
     "Download" : "ดาวน์โหลด",
@@ -22,7 +21,10 @@ OC.L10N.register(
     "Address book name" : "สมุดชื่อที่อยู่",
     "First name" : "ชื่อจริง",
     "Last name" : "นามสกุลจริง",
+    "Group name" : "ชื่อกลุ่ม",
     "Not grouped" : "ไม่ถูกจัดกลุ่ม",
+    "Close" : "ปิด",
+    "Import" : "นำเข้า",
     "Nickname" : "ชื่อเล่น",
     "Detailed name" : "รายละเอียดชื่อ",
     "Additional names" : "ชื่ออื่นๆ",
